//Http配置
import Axios from 'axios'
import {
	Message
} from 'element-ui'
import router from "../../router"
import TokenManager from "./TokenManager"

Axios.defaults.timeout = 10000; // 超时时间
Axios.defaults.headers['verify'] = 'mqtt'; // 验证
Axios.defaults.headers['Content-Type'] = `application/x-www-form-urlencoded`;

/**
 * 拦截http请求
 */
Axios.interceptors.request.use(config => {
	// 判断是否存在token，如果存在的话，则每个http header都加上token
	try {
		const obj = JSON.parse(TokenManager.getToken());
		config.headers['token'] = obj.token;
	} catch {
		return config;
	}
	return config;
});

/**
 * 拦截http响应
 */
Axios.interceptors.response.use(res => {
	const status = res.data.status; //状态码
	switch (status) {
		case 300: //警告
			Message.warning({
				message: res.data.msg
			});
			return Promise.reject(res.data);
		case 401: //登录
			Message.warning({
				message: "验证信息过期,请重新登录",
				duration: 5000
			});
			router.replace("/login");
			return Promise.reject(res.data);
		case 500: //服务器错误
			Message.error({
				message: "服务器开小差了"
			});
			return Promise.reject(res.data);
		default:
			return res.data;
	}
}, error => {
	return Promise.reject(error)
});

export default Axios
